<?php
namespace WPCommander\Models;

defined( 'ABSPATH' ) || exit;

class ConfigModel {
    const OPTION_KEY = 'wpcommander_config';
    const DEFAULT_CONFIG = [
        'roles' => [ 'administrator' ],
        'folder_access_type' => FoldersModel::COMMON_FOLDERS,
        'default_color' => NULL,
        'disable_counter' => false,
        'disable_ajax' => false,
        'infinite_scrolling' => false,
        'uninstall_fully' => false
    ];

    public static function init() {
        self::set();
    }

    public static function get( $option = null ) {
        $data = get_option( self::OPTION_KEY );
        if ( $data && $option != null ) {
            return $data[ $option ];
        }
        return $data ? $data : null;
    }

    public static function set( $data = null ) {
        $data = $data ? $data : self::get();
        $data = $data ? $data : [];

        foreach ( self::DEFAULT_CONFIG as $key => $option ) {
            if ( !array_key_exists( $key, $data ) ) {
                $data[$key] = $option;
            }
        }

        foreach ( $data as $key => $option ) {
            if ( !array_key_exists( $key, self::DEFAULT_CONFIG ) ) {
                unset( $data[$key] );
            }
        }

        if ( get_option( self::OPTION_KEY ) == false ) {
            $deprecated = null;
            $autoload = 'no';
            return add_option( self::OPTION_KEY, $data, $deprecated, $autoload );
        } else {
            $old_value = get_option( self::OPTION_KEY );
            if ( $old_value === $data ) {
                return true;
            } else {
                return update_option( self::OPTION_KEY, $data );
            }
        }
    }

    public static function getToken() {
        global $wp_version;
        $current_user = wp_get_current_user();

        $data = [
            'plugin_name' => WPCOMMANDER_PLUGIN_NAME,
            'plugin_version' => WPCOMMANDER_PLUGIN_VERSION,
            'wordpress' => $wp_version,
            'php' => PHP_VERSION,
            'email' => $current_user->user_email,
            'site' => trim( str_replace( [ 'http://', 'https://' ], '', get_site_url() ), '/' )
        ];

        return base64_encode( json_encode( $data ) );
    }
}
