<?php
namespace WPCommander\Rest\Controllers;

defined( 'ABSPATH' ) || exit;

use WPCommander\Models\FoldersModel;
use WPCommander\Models\HelperModel;
use WPCommander\Models\UserModel;

class FoldersController {
    public function registerRestRoutes() {
        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/meta',
            [
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => [ $this, 'getMeta' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ],
                [
                    'methods' => \WP_REST_Server::EDITABLE,
                    'callback' => [ $this, 'updateMeta' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/folder-access-types',
            [
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => [ $this, 'getFolderAccessTypes' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/folders',
            [
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => [ $this, 'getFolders' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ],
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => [ $this, 'createFolders' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ],
                [
                    'methods' => \WP_REST_Server::EDITABLE,
                    'callback' => [ $this, 'updateFolders' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ],
                [
                    'methods' => \WP_REST_Server::DELETABLE,
                    'callback' => [ $this, 'deleteFolders' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/copyfolder',
            [
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => [ $this, 'copyFolder' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/attach',
            [
                [
                    'methods' => \WP_REST_Server::EDITABLE,
                    'callback' => [ $this, 'attachToFolder' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/attachment/counters',
            [
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => [ $this, 'getAttachmentCounters' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ],
                [
                    'methods' => \WP_REST_Server::EDITABLE,
                    'callback' => [ $this, 'updateAttachmentCounters' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/export-csv',
            [
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => [ $this, 'exportCSV' ],
                    'permission_callback' => [ $this, 'canUploadFiles' ]
                ]
            ]
        );

        register_rest_route(
            WPCOMMANDER_PLUGIN_REST_URL,
            '/import-csv',
            [
                'methods'             => \WP_REST_Server::CREATABLE,
                'callback'            => [ $this, 'importCSV' ],
                'permission_callback' => [ $this, 'canUploadFiles' ]
            ]
        );
    }

    public function canUploadFiles() {
        return current_user_can( 'upload_files' );
    }

    public function getMeta( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );

        $data = UserModel::getMeta( $type );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function updateMeta( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $meta  = $request->get_param( 'meta' );

        $data = UserModel::updateMeta( $type, $meta );
        $response = isset( $data ) ? [ 'success' => true ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function getFolderAccessTypes( \WP_REST_Request $request ) {
        $response = [
            'success' => true,
            'data' => FoldersModel::getFolderAccessTypes()
        ];

        return new \WP_REST_Response( $response );
    }

    public function getFolders( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );

        $data = FoldersModel::getFolders( $type );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function createFolders( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $parent = intval( $request->get_param( 'parent' ) );
        $names = array_map( 'sanitize_text_field', $request->get_param( 'names' ) ? $request->get_param( 'names' ) : [] );
        $color = HelperModel::filterColor( $request->get_param( 'color' ) );

        $data = FoldersModel::createFolders( $type, $parent, $names, $color );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function updateFolders( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $action  = sanitize_key( $request->get_param( 'action' ) );
        $ids = $request->has_param( 'folders' ) ? array_map( 'intval', $request->get_param( 'folders' ) ) : [];
        $attrs = [
            'name' => sanitize_text_field( $request->get_param( 'name' ) ),
            'color' => HelperModel::filterColor( $request->get_param( 'color' ) ),
            'parent' => intval( $request->get_param( 'parent' ) ),
            'sorting' => $request->has_param( 'sorting' ) ? array_map( 'intval', $request->get_param( 'sorting' ) ) : []
        ];

        $data = FoldersModel::updateFolders( $type, $action, $ids, $attrs );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function copyFolder( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $src = intval( $request->get_param( 'src' ) );
        $dst = intval( $request->get_param( 'dst' ) );

        $data = FoldersModel::copyFolder( $type, $src, $dst );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function deleteFolders( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $ids = $request->has_param( 'folders' ) ? array_map( 'intval', $request->get_param( 'folders' ) ) : [];

        $data = FoldersModel::deleteFolders( $type, $ids );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function attachToFolder( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $id  = sanitize_key( $request->get_param( 'folder' ) );
        $attachments = $request->has_param( 'attachments' ) ? array_map( 'intval', $request->get_param( 'attachments' ) ) : [];

        $data = FoldersModel::attachToFolder( $type, $id, $attachments );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function getAttachmentCounters( \WP_REST_Request $request ) {
        $type  = sanitize_key( $request->get_param( 'type' ) );
        $ids = array_map( 'intval', $request->get_param( 'folders' ) ? $request->get_param( 'folders' ) : [] );

        $data = FoldersModel::getAttachmentCounters( $type, $ids );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function updateAttachmentCounters( \WP_REST_Request $request ) {
        $response = [ 'success' => FoldersModel::updateAttachmentCounters() ];
        return new \WP_REST_Response( $response );
    }

    public function exportCSV( \WP_REST_Request $request ) {
        $data = FoldersModel::exportCSV();
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

    public function importCSV( \WP_REST_Request $request ) {
        $params  = $request->get_file_params();
        $file = $params['file']['tmp_name'];
        $clear  = filter_var( $request->get_param( 'clear' ), FILTER_VALIDATE_BOOLEAN );
        $attachments  = filter_var( $request->get_param( 'attachments' ), FILTER_VALIDATE_BOOLEAN );

        $data = FoldersModel::importCSV( $file, $clear, $attachments );
        $response = isset( $data ) ? [ 'success' => true, 'data' => $data ] : [ 'success' => false ];

        return new \WP_REST_Response( $response );
    }

}