<?php
namespace WPCommander\System;

defined( 'ABSPATH' ) || exit;

use WPCommander\Models\ConfigModel;

class Installer {
    public function __construct() {
        self::init();
    }

    private function init() {
        self::initConfig();

        if ( version_compare( get_option( 'wpcommander_version' ), WPCOMMANDER_PLUGIN_VERSION, '<' ) ) {
            self::updateVersion();
        }

        self::createDbTables();
        self::initDbTables();

        if ( version_compare( get_option( 'wpcommander_db_version' ), WPCOMMANDER_PLUGIN_DB_VERSION, '<' ) ) {
            self::updateDbVersion();
        }
    }

    private function initConfig() {
        ConfigModel::init();
    }

    private function updateVersion() {
        update_option( 'wpcommander_version', WPCOMMANDER_PLUGIN_VERSION );
    }

    private function getDbSchema() {
        global $wpdb;

        $charsetCollate = $wpdb->has_cap( 'collation' ) ? $wpdb->get_charset_collate() : '';

        $tableFolders = $wpdb->prefix . WPCOMMANDER_PLUGIN_DB_TABLE_PREFIX . '_folders';
        $tableAttachments = $wpdb->prefix . WPCOMMANDER_PLUGIN_DB_TABLE_PREFIX . '_attachments';

        $tables = "
            CREATE TABLE {$tableFolders} (
                id bigint unsigned NOT NULL AUTO_INCREMENT,
                parent bigint unsigned NOT NULL DEFAULT 0,
                type varchar(20) NOT NULL DEFAULT 'attachment',
                owner bigint NOT NULL DEFAULT 0,
                title varchar(255) NOT NULL DEFAULT '',
                color varchar(7) NOT NULL DEFAULT '',
                ord bigint unsigned NOT NULL DEFAULT 0,
                count bigint unsigned NOT NULL DEFAULT 0,
                created_by bigint NOT NULL DEFAULT 0,
                modified_by bigint NOT NULL DEFAULT 0,
                created datetime NOT NULL,
                modified datetime NOT NULL,
                PRIMARY KEY (id)
		    ) {$charsetCollate};

            CREATE TABLE {$tableAttachments} (
                folder_id bigint unsigned NOT NULL,
                attachment_id bigint unsigned NOT NULL,
                UNIQUE KEY `folder_attachment` (`folder_id`,`attachment_id`)
            ) {$charsetCollate};
        ";

        return $tables;
    }

    private function createDbTables() {
        global $wpdb;
        $wpdb->hide_errors();

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( self::getDbSchema() );
    }

    private function initDbTables() {
    }

    private function updateDbVersion() {
        update_option( 'wpcommander_db_version', WPCOMMANDER_PLUGIN_DB_VERSION );
    }
}