<?php
namespace WPCommander\System;

defined( 'ABSPATH' ) || exit;

class Notice {
    public function __construct() {
        add_action( 'init', [ $this, 'init' ] );
    }

    public function init() {
        add_action( 'admin_notices', [ $this, 'adminNotices' ] );
        add_action( 'admin_enqueue_scripts', [ $this, 'enqueueScripts' ] );
    }

    public function adminNotices() {
        if ( get_option( 'wpcommander_dismiss_first_use_notification', false ) || ( get_current_screen() && get_current_screen()->base === 'upload' ) ) {
            return;
        }

        $classes = [
            'notice',
            'notice-info',
            'is-dismissible',
        ];

        $msg = sprintf(
            '<span>' . esc_html__( "Thanks for start using the plugin WP Commander. Let's create first folders. %s", 'wpcommander' ) . '</span>',
            '<a href="' . esc_url(admin_url('/upload.php')) . '">' . esc_html__( "Go to WordPress Media Library.", 'wpcommander' ) . '</a>'
        );
        printf( '<div id="wpcommander-first-use-notification" class="%s"><p>%s</p></div>', trim( implode( ' ', $classes ) ), $msg );
    }

    public function enqueueScripts() {
        wp_enqueue_style( 'wpcommander-notice', WPCOMMANDER_PLUGIN_URL . 'assets/css/notice.css', [], WPCOMMANDER_PLUGIN_VERSION );
        wp_enqueue_script( 'wpcommander-notice', WPCOMMANDER_PLUGIN_URL . 'assets/js/notice.js', ['jquery'], WPCOMMANDER_PLUGIN_VERSION, false );
        wp_localize_script( 'wpcommander-notice', 'wpcommander_notice_globals', $this->getGlobals() );
    }

    private function getGlobals() {
        $globals = [
            'api' => [
                'nonce' => wp_create_nonce( 'wp_rest' ),
                'url' => esc_url_raw( rest_url( WPCOMMANDER_PLUGIN_REST_URL ) )
            ]
        ];

        return $globals;
    }
}