<?php
namespace WPCommander\System;

defined( 'ABSPATH' ) || exit;

use WPCommander\Models\HelperModel;
use WPCommander\Models\ImportModel;

class Settings {
    public function __construct() {
        add_action( 'init', [ $this, 'init' ] );

    }

    public function init() {
        add_action( 'admin_menu', [ $this, 'adminMenu' ] );
        add_action ('in_admin_header', [$this, 'removeNotices'] );
    }

    public function adminMenu() {
       add_submenu_page(
            'options-general.php',
            'WP Commander Settings',
            'WP Commander',
            'manage_options',
            'wpcommander-settings',
            [ $this, 'adminMenuPageSettings' ]
        );
    }

    public function adminMenuPageSettings() {
        $page = sanitize_key( filter_input( INPUT_GET, 'page', FILTER_DEFAULT ) );
        if ( $page === 'wpcommander-settings' ) {
            $globals = [
                'data' => [
                    'plugins_to_import' => ImportModel::getPluginsToImport()
                ],
                'msg' => HelperModel::getMessagesForSettings(),
                'api' => [
                    'nonce' => wp_create_nonce( 'wp_rest' ),
                    'url' => esc_url_raw( rest_url( WPCOMMANDER_PLUGIN_REST_URL ) )
                ]
            ];

            wp_enqueue_script( 'wpcommander-feather-icons', WPCOMMANDER_PLUGIN_URL . 'assets/vendor/feather-icons/feather.js', [], WPCOMMANDER_PLUGIN_VERSION, false );
            wp_enqueue_script( 'wpcommander-angular-light', WPCOMMANDER_PLUGIN_URL . 'assets/vendor/angular-light/angular-light.js', [], WPCOMMANDER_PLUGIN_VERSION, false );
            wp_enqueue_script( 'wpcommander-cookies', WPCOMMANDER_PLUGIN_URL . 'assets/vendor/cookie/cookie.js', [], WPCOMMANDER_PLUGIN_VERSION, false );

            wp_enqueue_style( 'wpcommander-notify', WPCOMMANDER_PLUGIN_URL . 'assets/css/notify.css', [], WPCOMMANDER_PLUGIN_VERSION );
            wp_enqueue_script( 'wpcommander-notify', WPCOMMANDER_PLUGIN_URL . 'assets/js/notify.js', ['jquery'], WPCOMMANDER_PLUGIN_VERSION, false );

            wp_enqueue_style( 'wpcommander-colorpicker', WPCOMMANDER_PLUGIN_URL . 'assets/css/colorpicker.css', [], WPCOMMANDER_PLUGIN_VERSION );
            wp_enqueue_script( 'wpcommander-colorpicker', WPCOMMANDER_PLUGIN_URL . 'assets/js/colorpicker.js', ['jquery'], WPCOMMANDER_PLUGIN_VERSION, false );

            wp_enqueue_style( 'wpcommander-settings', WPCOMMANDER_PLUGIN_URL . 'assets/css/settings.css', [], WPCOMMANDER_PLUGIN_VERSION );
            wp_enqueue_script( 'wpcommander-settings', WPCOMMANDER_PLUGIN_URL . 'assets/js/settings.js', ['jquery'], WPCOMMANDER_PLUGIN_VERSION, false );
            wp_localize_script( 'wpcommander-settings', 'wpcommander_settings_globals', $globals);

            require_once( WPCOMMANDER_PLUGIN_PATH . '/includes/Views/settings.php' );
        }
    }

    public function removeNotices() {
        $page = sanitize_key( filter_input( INPUT_GET, 'page', FILTER_DEFAULT ) );
        if ( $page === 'wpcommander-settings' ) {
            remove_all_actions( 'admin_notices' );
            remove_all_actions( 'all_admin_notices' );
        }
    }
}
